@@ -74,7 +74,6 @@ def _resolve_filter_classes(cls_list):
             _LOG.exception(ae)
             raise ImportError('Unable to import: {}'.format(cdef))
 
-    _LOG.debug('Found filters: {}'.format(filter_cls_list))
     return filter_cls_list
 
 
@@ -106,8 +105,6 @@ def _build_singleton_plfactories(config):
     all_classes.extend(_resolve_filter_classes(config.pipeline.upstream))
     all_classes.extend(_resolve_filter_classes(config.pipeline.downstream))
 
-    _LOG.debug('Gathered filter classes: {}'.format(all_classes))
-
     for cls in all_classes:
         filter_instances[cls.__name__] = cls()
 
@@ -124,9 +121,6 @@ def _build_plfactories(config):
     downstream = _build_plfactory_closure(
         _resolve_filter_classes(config.pipeline.downstream))
 
-    _LOG.debug('Gathered upstream filter classes: {}'.format(upstream()))
-    _LOG.debug('Gathered downstream filter classes: {}'.format(downstream()))
-
     return upstream, downstream
 
 
@@ -176,10 +170,9 @@ def start_proxy(sockets, config):
     IOLoop.current().start()
 
 
-def start_pyrox(cfg=None, cfg_location=None):
-    config = cfg
+def start_pyrox(config):
     if config is None:
-        config = load_pyrox_config(cfg_location)
+        raise ConfigurationError('No configuration object passed in')
 
     # Log some important things
     if config.routing.upstream_hosts is not None:
