@@ -231,7 +231,7 @@ class UpstreamHandler(ProxyHandler):
 
                 self._http_msg.header('transfer-encoding').values.append('chunked')
 
-        if action.is_replying():
+        if action.is_rejecting():
             self._intercepted = True
             self._response_tuple = action.payload
         else:
