@@ -8,7 +8,7 @@
 import unittest
 
 import pyrox.http as http
-import pyrox.http.filtering as http_filtering
+import pyrox.filtering as http_filtering
 
 import pynsive
 
